# geogee


[![image](https://img.shields.io/pypi/v/geogee.svg)](https://pypi.python.org/pypi/geogee)
[![image](https://img.shields.io/conda/vn/conda-forge/geogee.svg)](https://anaconda.org/conda-forge/geogee)


**A python package for geogee**


-   Free software: MIT license
-   Documentation: https://LyMot.github.io/geogee
    

## Features

-   TODO
